@@ -2,8 +2,7 @@ library(manymodelr)
 testthat::test_that(desc = "expect get_mode error",
                     code={
                 testthat::expect_error(get_mode(iris$Species),
-            "No implementation available for objects of class
-             factor",
+            "No implementation available for objects of class factor",
                       fixed=TRUE)
                     })
 
@@ -16,6 +15,8 @@ testthat::test_that(desc="test get_mode",
         testthat::expect_equal(get_mode(test_vec), 1)
         testthat::expect_equal(get_mode(test_chr),"Apples")
         
+testthat::expect_warning(get_mode(iris),"factor columns converted to character",fixed=TRUE)
+        
                     })
 
 
