@@ -5,20 +5,15 @@ testthat::test_that(desc="Correlation tests",
                       
       test_data <- data.frame(A=rep(NA,12),B=rep(12,12))
       
-    testthat::expect_error(get_var_corr(test_data,
-                  comparison_var = "A",
-                   get_all = TRUE),
-      "Cannot perform correlation tests on columns with only NAs. Please
-         remove these or impute missing values with known methods. Alternatively, set use='complete.obs'
-         to use complete observations. See details in help(get_var_corr)",
-      fixed=TRUE)
+    testthat::expect_error(get_var_corr(test_data,comparison_var = "A"),
+      "Found columns with only NAs. Please remove these first.",fixed=TRUE)
+    testthat::expect_error(get_var_corr(iris),"comparison_var is required.", fixed=TRUE)
     
     testthat::expect_warning( get_var_corr(iris,"Sepal.Length",
                                            drop_columns = c("factor")),
                              "Columns with classes in drop_columns have been discarded. You
               can disable this by setting yourself by setting drop_columns
-              to NULL.",
-                             fixed=TRUE)
+              to NULL.", fixed=TRUE)
   
     
     # Test that when a user changes the method, it actually works.
@@ -26,8 +21,7 @@ testthat::test_that(desc="Correlation tests",
     testthat::expect_true("lower_ci" %in% names(get_var_corr(mtcars,"mpg")))
     # Now switch things up, expect length 4
     testthat::expect_true(length(names(get_var_corr(mtcars,"mpg",
-                                     method = "spearman",
-                                     exact = FALSE))) == 4)
+                                     method = "spearman",exact = FALSE))) == 4)
                     })
 
 
